# ActivitiesSummaryV20

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**last_modified_date** | [**LastModifiedDateV20**](LastModifiedDateV20.md) |  | [optional] 
**educations** | [**EducationsSummaryV20**](EducationsSummaryV20.md) |  | [optional] 
**employments** | [**EmploymentsSummaryV20**](EmploymentsSummaryV20.md) |  | [optional] 
**fundings** | [**FundingsV20**](FundingsV20.md) |  | [optional] 
**peer_reviews** | [**PeerReviewsV20**](PeerReviewsV20.md) |  | [optional] 
**works** | [**WorksSummaryV20**](WorksSummaryV20.md) |  | [optional] 
**path** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

